Product class

Constructors

Product({String? title, double? price, String? image, String? category, String? description, required int id})
Product.fromJson(Map<String, dynamic> json)
factory

Properties

category String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
image String?
final
price double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited